@@ -15,6 +15,14 @@
 # limitations under the License.
 #===============================================================================
 
-from .svm import SVC
 
-__all__ = ['SVC']
+from .._utils import get_sklearnex_version
+if get_sklearnex_version((2021, 'P', 300)):
+    from .svr import SVR
+    from .svc import SVC
+    from .nusvr import NuSVR
+    from .nusvc import NuSVC
+    __all__ = ['SVR', 'SVC', 'NuSVC', 'NuSVR']
+else:
+    from daal4py.sklearn.svm import SVC
+    __all__ = ['SVC']
